BatchQC-Raw

# Batch Effect QC Report

####

#####

# Data Information

## Basic Describe

#### · Number of samples in each Batch and Condition

#### · Variation Analysis (F Test) of Each Data

#### · K-S Test of Each Pair Batch

#### · Domain Variance Score

#### · Measures of confounding between Batch and Condition

#### · Distribution Visualization

## Metric Score

### Raw

#### · K Nearest Neighbor Batch Effects Test

#### · Local Inverse Simpson's Index

#### · K Nearest Neighbor Similarity

## Visualization

#### · Sample

#### · Q-Q Cross Fit

#### · Q-Q Fit Norm & Histogram

## Summary

####